@@ -1,16 +1,14 @@
-import json
-import re
 from base64 import b64decode
-from re import sub
+from re import match, sub
 
+from aiohttp import ClientSession
 from dotmap import DotMap
-from httpx import AsyncClient
 from pyrogram.types import Message, User
 
 
 # https://stackoverflow.com/a/55766564/13673785
 def _format_url(url):
-    if not re.match("(?:http|https)://", url):
+    if not match("(?:http|https)://", url):
         return "https://{}".format(url)
     return url
 
@@ -40,7 +38,7 @@ class Arq:
 
     Methods
     -------
-    deezer(query="never gonna give you up", limit=1):
+    deezer(query="never gonna give you up", count=1, format=3):
         Get songs from deezer.
             Returns result object with 'limit' number of result which you can use access dot notation.
 
@@ -52,6 +50,10 @@ class Arq:
         Get songs from Saavn.
             Returns result object with 4-5 results which you can access with dot notation.
 
+    splaylist(url):
+        Get Saavn playlist songs.
+            Returns result object with an array of songs.
+
     youtube(query="carry minati"):
         Search on youtube.
             Returns result object which you can access with dot notation.
@@ -116,37 +118,37 @@ class Arq:
             returns result object.
     """
 
-    def __init__(self, api_url: str, api_key: str, **options):
+    def __init__(
+        self, api_url: str, api_key: str, aiohttp_session: ClientSession
+    ):
         self.api_url = _format_url(api_url.strip(" /"))
         self.api_key = api_key
-        self.session = AsyncClient(**options)
+        self.session = aiohttp_session
 
     async def _fetch(self, route, **params):
-        async with self.session as s:
-            resp = await s.get(
-                f"{self.api_url}/{route}",
-                headers={"X-API-KEY": self.api_key},
-                params=params,
-            )
-            if resp.status_code in (401, 403):
+        async with self.session.get(
+            f"{self.api_url}/{route}",
+            headers={"X-API-KEY": self.api_key},
+            params=params,
+        ) as resp:
+            if resp.status in (401, 403):
                 raise InvalidApiKey(
                     "Invalid API key, Get an api key from @ARQRobot"
                 )
-        response = resp.json()
+            response = await resp.json()
         return DotMap(response)
 
     async def _post(self, route, payload):
-        async with self.session as s:
-            resp = await s.post(
-                f"{self.api_url}/{route}",
-                headers={"X-API-KEY": self.api_key},
-                params={"payload": str(payload)},
-            )
-            if resp.status_code in (401, 403):
+        async with self.session.post(
+            f"{self.api_url}/{route}",
+            headers={"X-API-KEY": self.api_key},
+            params={"payload": str(payload)},
+        ) as resp:
+            if resp.status in (401, 403):
                 raise InvalidApiKey(
                     "Invalid API key, Get an api key from @ARQRobot"
                 )
-        response = resp.json()
+            response = await resp.json()
         if response.get("ok"):
             response["result"] = b64decode(
                 sub("data:image/png;base64", "", response["result"])
@@ -154,21 +156,26 @@ class Arq:
             return DotMap(response)
         return DotMap(response)
 
-    async def deezer(self, query: str, count: int):
+    async def deezer(self, query: str, count: int = 1, format: int = 3):
         """
         Returns An Object.
 
                 Parameters:
-                        query (int): Query to search
+                        query (str): Query to search
                         count (int): Number of results to return
+                        format (int): Quality [Bitrate] of songs.
+                                      Available formats:  1 - MP3 128kbit,
+                                                          3 - MP3 320kbit,
+                                                          9 - Lossless(FLAC),
+                                      Defaults to 3, MP3 320Kbps.
                 Returns:
-                        result object (str): Results which you can access with dot notation, Ex - results[result_number].url
+                        results: Results which you can access with dot notation, Ex - results[result_number].url
 
                         result[result_number].title | .id | .source | .duration | .thumbnail | .thumbnailBig |.artist
                             .artistPictures | .url
 
         """
-        return await self._fetch("deezer", query=query, count=count)
+        return await self._fetch("deezer", query=query, count=count, format=format)
 
     async def torrent(self, query: str):
         """
@@ -196,6 +203,19 @@ class Arq:
         """
         return await self._fetch("saavn", query=query)
 
+    async def splaylist(self, url: str):
+        """
+        Returns An Object.
+
+                Parameters:
+                        url (str): Saavn playlist url
+                Returns:
+                        Result object (str): Results which you can access with dot notation
+
+        """
+        return await self._fetch("splaylist", url=url)
+
+
     async def youtube(self, query: str):
         """
         Returns An Object.
